@@ -1,20 +1,19 @@
 '''
 [![npm version](https://badge.fury.io/js/cdk-github.svg)](https://badge.fury.io/js/cdk-github)
 [![PyPI version](https://badge.fury.io/py/cdk-github.svg)](https://badge.fury.io/py/cdk-github)
-[![NuGet version](https://badge.fury.io/nu/cdkgithub.svg)](https://badge.fury.io/nu/cdkgithub)
 [![release](https://github.com/wtfjoke/cdk-github/actions/workflows/release.yml/badge.svg)](https://github.com/wtfjoke/cdk-github/actions/workflows/release.yml)
 ![cdk-constructs: Experimental](https://img.shields.io/badge/cdk--constructs-experimental-important.svg?style=for-the-badge)
 
 # CDK-GitHub
 
-GitHub Constructs for use in [AWS CDK](https://aws.amazon.com/cdk/) .
+[AWS CDK](https://aws.amazon.com/cdk/) v2 L3 constructs for GitHub.
 
 This project aims to make GitHub's API accessible through CDK with various helper constructs to create resources in GitHub.
-The target is to replicate most of the functionality of the official [Terraform GitHub Provider](https://registry.terraform.io/providers/integrations/github/latest/docs).
+The target is to replicate most of the functionality of the [Terraform GitHub Provider](https://registry.terraform.io/providers/integrations/github/latest/docs).
 
-Internally [AWS CloudFormation custom resources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-custom-resources.html) and [octokit](https://github.com/octokit/core.js) are used to manage GitHub resources (such as Secrets).
+Internally [AWS CloudFormation custom resources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-custom-resources.html) will be used to track GitHub resources (such as Secrets).
 
-# 🔧 Installation
+# Installation
 
 JavaScript/TypeScript:
 `npm install cdk-github`
@@ -22,28 +21,22 @@ JavaScript/TypeScript:
 Python:
 `pip install cdk-github`
 
-# 📚 Constructs
+# Constructs
 
 This library provides the following constructs:
 
 * [ActionSecret](API.md#actionsecret-a-nameactionsecret-idcdk-githubactionsecreta) - Creates a [GitHub Action (repository) secret](https://docs.github.com/en/actions/security-guides/encrypted-secrets#creating-encrypted-secrets-for-a-repository) from a given AWS Secrets Manager secret.
 * [ActionEnvironmentSecret](API.md#actionenvironmentsecret-a-nameactionenvironmentsecret-idcdk-githubactionenvironmentsecreta) - Creates a [GitHub Action environment secret](https://docs.github.com/en/actions/security-guides/encrypted-secrets#creating-encrypted-secrets-for-an-environment) from a given AWS Secrets Manager secret.
 
-# 🔓 Authentication
+# Authentication
 
 Currently the constructs only support authentication via a [GitHub Personal Access Token](https://github.com/settings/tokens/new). The token needs to be a stored in a AWS SecretsManager Secret and passed to the construct as parameter.
 
-# 👩‍🏫 Examples
-
-The API documentation and examples in different languages are available on [Construct Hub](https://constructs.dev/packages/cdk-github).
-All (typescript) examples can be found in the folder [examples](src/examples/).
+# Examples
 
 ## ActionSecret
 
 ```python
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
-import { Construct } from 'constructs';
 import { ActionSecret } from 'cdk-github';
 
 export class ActionSecretStack extends Stack {
@@ -64,12 +57,39 @@ export class ActionSecretStack extends Stack {
 }
 ```
 
+See full example in [ActionSecretStack](src/examples/action-secret/action-secret-stack.ts)
+
+### Python
+
+```python
+import cdkgithub
+
+class ActionSecretStack(Stack):
+    def __init__(self, scope: Construct, construct_id: str, **kwargs) -> None:
+        super().__init__(scope, construct_id, **kwargs)
+
+        source_secret = sm.Secret.from_secret_name_v2(
+            self, "secretToStoreInGitHub", "testcdkgithub"
+        )
+        github_token_secret = sm.Secret.from_secret_name_v2(
+            self, "ghSecret", "GITHUB_TOKEN"
+        )
+        cdkgithub.ActionSecret(
+            self,
+            "GitHubActionSecret",
+            github_token_secret=github_token_secret,
+            repository_name="cdk-github",
+            repository_owner="wtfjoke",
+            repository_secret_name="aRandomPythonGitHubSecret",
+            source_secret=source_secret,
+        )
+```
+
+Please note: the module name is `cdkgithub` and not `cdk-github`.
+
 ## ActionEnvironmentSecret
 
 ```python
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
-import { Construct } from 'constructs';
 import { ActionEnvironmentSecret } from 'cdk-github';
 
 export class ActionEnvironmentSecretStack extends Stack {
@@ -91,9 +111,7 @@ export class ActionEnvironmentSecretStack extends Stack {
 }
 ```
 
-# 💖 Contributing
-
-Contributions of all kinds are welcome! Check out our [contributing guide](CONTRIBUTING.md).
+See full example in [ActionEnvironmentSecretStack](src/examples/action-environment-secret/action-environment-secret-stack.ts)
 '''
 import abc
 import builtins
@@ -116,10 +134,6 @@ class ActionEnvironmentSecret(
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-github.ActionEnvironmentSecret",
 ):
-    '''
-    :stability: experimental
-    '''
-
     def __init__(
         self,
         scope: constructs.Construct,
@@ -135,14 +149,12 @@ class ActionEnvironmentSecret(
         '''
         :param scope: -
         :param id: -
-        :param environment: (experimental) The GithHub environment name which the secret should be stored in.
-        :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: (experimental) The GitHub repository name.
-        :param repository_owner: (experimental) The GitHub repository owner.
-        :param repository_secret_name: (experimental) The GitHub secret name to be stored.
-        :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
-
-        :stability: experimental
+        :param environment: The GithHub environment which the secret should be stored in.
+        :param github_token_secret: The AWS secret in which the OAuth GitHub (personal) access token is stored.
+        :param repository_name: The GitHub repository name.
+        :param repository_owner: The GitHub repository owner.
+        :param repository_secret_name: The GitHub secret name to be stored.
+        :param source_secret: The AWS secret which should be stored as a GitHub as a secret.
         '''
         props = ActionEnvironmentSecretProps(
             environment=environment,
@@ -180,14 +192,12 @@ class ActionEnvironmentSecretProps:
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
     ) -> None:
         '''
-        :param environment: (experimental) The GithHub environment name which the secret should be stored in.
-        :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: (experimental) The GitHub repository name.
-        :param repository_owner: (experimental) The GitHub repository owner.
-        :param repository_secret_name: (experimental) The GitHub secret name to be stored.
-        :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
-
-        :stability: experimental
+        :param environment: The GithHub environment which the secret should be stored in.
+        :param github_token_secret: The AWS secret in which the OAuth GitHub (personal) access token is stored.
+        :param repository_name: The GitHub repository name.
+        :param repository_owner: The GitHub repository owner.
+        :param repository_secret_name: The GitHub secret name to be stored.
+        :param source_secret: The AWS secret which should be stored as a GitHub as a secret.
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "environment": environment,
@@ -200,60 +210,42 @@ class ActionEnvironmentSecretProps:
 
     @builtins.property
     def environment(self) -> builtins.str:
-        '''(experimental) The GithHub environment name which the secret should be stored in.
-
-        :stability: experimental
-        '''
+        '''The GithHub environment which the secret should be stored in.'''
         result = self._values.get("environment")
         assert result is not None, "Required property 'environment' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def github_token_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
-        '''(experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
-
-        :stability: experimental
-        '''
+        '''The AWS secret in which the OAuth GitHub (personal) access token is stored.'''
         result = self._values.get("github_token_secret")
         assert result is not None, "Required property 'github_token_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
 
     @builtins.property
     def repository_name(self) -> builtins.str:
-        '''(experimental) The GitHub repository name.
-
-        :stability: experimental
-        '''
+        '''The GitHub repository name.'''
         result = self._values.get("repository_name")
         assert result is not None, "Required property 'repository_name' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def repository_owner(self) -> builtins.str:
-        '''(experimental) The GitHub repository owner.
-
-        :stability: experimental
-        '''
+        '''The GitHub repository owner.'''
         result = self._values.get("repository_owner")
         assert result is not None, "Required property 'repository_owner' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def repository_secret_name(self) -> builtins.str:
-        '''(experimental) The GitHub secret name to be stored.
-
-        :stability: experimental
-        '''
+        '''The GitHub secret name to be stored.'''
         result = self._values.get("repository_secret_name")
         assert result is not None, "Required property 'repository_secret_name' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def source_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
-        '''(experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
-
-        :stability: experimental
-        '''
+        '''The AWS secret which should be stored as a GitHub as a secret.'''
         result = self._values.get("source_secret")
         assert result is not None, "Required property 'source_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
@@ -275,10 +267,6 @@ class ActionSecret(
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-github.ActionSecret",
 ):
-    '''
-    :stability: experimental
-    '''
-
     def __init__(
         self,
         scope: constructs.Construct,
@@ -293,13 +281,11 @@ class ActionSecret(
         '''
         :param scope: -
         :param id: -
-        :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: (experimental) The GitHub repository name.
-        :param repository_owner: (experimental) The GitHub repository owner.
-        :param repository_secret_name: (experimental) The GitHub secret name to be stored.
-        :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
-
-        :stability: experimental
+        :param github_token_secret: The AWS secret in which the OAuth GitHub (personal) access token is stored.
+        :param repository_name: The GitHub repository name.
+        :param repository_owner: The GitHub repository owner.
+        :param repository_secret_name: The GitHub secret name to be stored.
+        :param source_secret: The AWS secret which should be stored as a GitHub as a secret.
         '''
         props = ActionSecretProps(
             github_token_secret=github_token_secret,
@@ -334,13 +320,11 @@ class ActionSecretProps:
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
     ) -> None:
         '''
-        :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
-        :param repository_name: (experimental) The GitHub repository name.
-        :param repository_owner: (experimental) The GitHub repository owner.
-        :param repository_secret_name: (experimental) The GitHub secret name to be stored.
-        :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
-
-        :stability: experimental
+        :param github_token_secret: The AWS secret in which the OAuth GitHub (personal) access token is stored.
+        :param repository_name: The GitHub repository name.
+        :param repository_owner: The GitHub repository owner.
+        :param repository_secret_name: The GitHub secret name to be stored.
+        :param source_secret: The AWS secret which should be stored as a GitHub as a secret.
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "github_token_secret": github_token_secret,
@@ -352,50 +336,35 @@ class ActionSecretProps:
 
     @builtins.property
     def github_token_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
-        '''(experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
-
-        :stability: experimental
-        '''
+        '''The AWS secret in which the OAuth GitHub (personal) access token is stored.'''
         result = self._values.get("github_token_secret")
         assert result is not None, "Required property 'github_token_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
 
     @builtins.property
     def repository_name(self) -> builtins.str:
-        '''(experimental) The GitHub repository name.
-
-        :stability: experimental
-        '''
+        '''The GitHub repository name.'''
         result = self._values.get("repository_name")
         assert result is not None, "Required property 'repository_name' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def repository_owner(self) -> builtins.str:
-        '''(experimental) The GitHub repository owner.
-
-        :stability: experimental
-        '''
+        '''The GitHub repository owner.'''
         result = self._values.get("repository_owner")
         assert result is not None, "Required property 'repository_owner' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def repository_secret_name(self) -> builtins.str:
-        '''(experimental) The GitHub secret name to be stored.
-
-        :stability: experimental
-        '''
+        '''The GitHub secret name to be stored.'''
         result = self._values.get("repository_secret_name")
         assert result is not None, "Required property 'repository_secret_name' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def source_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
-        '''(experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
-
-        :stability: experimental
-        '''
+        '''The AWS secret which should be stored as a GitHub as a secret.'''
         result = self._values.get("source_secret")
         assert result is not None, "Required property 'source_secret' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
